@@ -1,14 +1,10 @@
-if [ -x /usr/bin/update-mime-database ]; then
-  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
-fi
-
 if [ -x /usr/bin/update-desktop-database ]; then
   /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
 fi
 
 if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
   if [ -x /usr/bin/gtk-update-icon-cache ]; then
-    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
+    /usr/bin/gtk-update-icon-cache -f usr/share/icons/hicolor >/dev/null 2>&1
   fi
 fi
 
@@ -19,7 +15,7 @@ if [ -e usr/share/glib-2.0/schemas ]; then
 fi
 ( cd usr/bin ; rm -rf gnome-maps )
 ( cd usr/bin ; ln -sf /usr/share/gnome-maps/org.gnome.Maps gnome-maps )
-( cd usr/lib64/gnome-maps ; rm -rf libgnome-maps.so.0 )
-( cd usr/lib64/gnome-maps ; ln -sf libgnome-maps.so.0.0.0 libgnome-maps.so.0 )
 ( cd usr/lib64/gnome-maps ; rm -rf libgnome-maps.so )
 ( cd usr/lib64/gnome-maps ; ln -sf libgnome-maps.so.0 libgnome-maps.so )
+( cd usr/lib64/gnome-maps ; rm -rf libgnome-maps.so.0 )
+( cd usr/lib64/gnome-maps ; ln -sf libgnome-maps.so.0.0.0 libgnome-maps.so.0 )
